@@ -28,11 +28,6 @@ int main(int argc, char **argv)
     FileSystemMessage msg;
     FileSystemMount mounts[MAX_MOUNTS];
 
-    /* Initialize terminal as standard I/O. */
-    for (int i = 0; i < 3; i++)
-    {
-        while (open("/dev/tty0", ZERO) < 0);
-    }
     /* Ask filesystem for active mounts. */
     msg.action = MountInfo;
     msg.buffer = (char *) &mounts;
