@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Niek Linnenbank
+ * Copyright (C) 2009 Coen Bijlsma
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,29 +15,28 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <StringTokenizer.h>
+#include <String.h>
+#include <URI.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
 
 int main(int argc, char **argv)
 {
-	/* Initialize terminal as stdio */
-	for( int i = 0; i < 3; i++)
-	{
-		while(open("/dev/tty0", ZERO) < 0);
-	}
-	
-	String s("foo bar blaat hoi");
-	
-	StringTokenizer st(s, ' ');
-	
-	while( st.hasNext() )
-	{
-		printf( *(st.next()) );
-		printf("\n");
-	}
-	
-	printf("Done\n");
-	return 0;
+    String u1("http://coen@my.site\%2enl/file.php?query#fragment");
+    String u2("http://my.site.nl");
+        
+    URI uri1(*u1);
+    URI uri2(*u2);
+        
+    printf("URI1 == %s\n", uri1.getRawURI());
+    printf("URI2 == %s\n", uri2.getRawURI());
+    printf("URI1 has scheme %s\n", uri1.getScheme() );
+    printf("URI1 has hierarchical: %s\n", uri1.getHierarchical() );
+    printf("URI1 has query: %s\n", uri1.getQuery() );
+    printf("URI1 has fragment: %s\n", uri1.getFragment() );
+    printf("URI1 equals URI2: %s\n", (uri1.equals(uri2) ? "true" : "false") );
+    printf("URI1 normalized == %s\n", uri1.normalize() );
+
+    return EXIT_SUCCESS;
 }
