@@ -25,24 +25,33 @@
 int WriteCommand::execute(Size nparams, char **params)
 {
     int fd;
+    char space = ' ', *newline = "\r\n";
 
     /* Attempt to open the file first. */
-    if ((fd = open(params[0], ZERO)) < 0)
+    if ((fd = open(params[0], O_WRONLY)) < 0)
     {
         printf("Failed to open '%s': %s\r\n",
                 params[0], strerror(errno));
         return errno;
     }
     /* Write to the file. */
-    if (write(fd, params[1], strlen(params[1])) < 0)
+    for (Size i = 0; i < nparams - 1; i++)
     {
-	printf("Failed to write '%s': %s\r\n",
-		params[0], strerror(errno));
-	return errno;
+	/* Write the argument, and a whitespace. */
+	if (write(fd, params[i + 1], strlen(params[i + 1])) < 0 ||
+	    write(fd, &space, 1) < 0)
+	{
+	    printf("Failed to write '%s': %s\r\n",
+		    params[0], strerror(errno));
+	    return errno;
+	}	
     }
+    /* Newline. */
+    write(fd, newline, 2);
+    
     /* Close the file. */
     close(fd);
     return 0;
 }
 
-INITOBJ(WriteCommand, writeCmd, DEFAULT)
+INITOBJ(WriteCommand, writeCmd, LIBCRT_DEFAULT)
