@@ -1,15 +1,15 @@
 #ifndef __VERSION_H
 #define __VERSION_H
 
-#define VERSIONCODE 1
+#define VERSIONCODE 2
 #define VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
-#define RELEASE   "0.0.1-r106"
+#define RELEASE   "0.0.2-r189"
 #define COPYRIGHT "Copyright (C) 2009 Niek Linnenbank\r\n" \
                   "This is free software; see the source for copying conditions.  There is NO\r\n" \
                   "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\r\n\r\n"
 
 #define COMPILER  "i686-pc-linux-gnu-gcc (Gentoo 4.4.0 p1.1) 4.4.0"
-#define DATETIME  "2009-06-12 22:23:55.827548"
+#define DATETIME  "2009-07-03 15:18:00.426907"
 #define ARCH      "X86"
 
 #define BUILDUSER "fox"
@@ -19,7 +19,7 @@
 #define BUILDCPU  "Intel(R) Core(TM)2 CPU T5600 @ 1.83GHz"
 #define BUILDPY   "Python 2.5.4"
 #define BUILDER   "SCons 1.2.0"
-#define BUILDPATH "/home/fox/svn/svn.hunix.nl-freenos/trunk"
-#define BUILDURL  "https://svn.hunix.nl/project/FreeNOS/trunk"
+#define BUILDPATH "/home/fox/svn/FreeNOS/trunk"
+#define BUILDURL  "https://FreeNOS.googlecode.com/svn/trunk"
 
 #endif
