@@ -16,12 +16,12 @@
  */
 
 #include <FreeNOS/Process.h>
-#include <Vector.h>
+#include <Array.h>
 #include <Types.h>
 #include <Config.h>
 #include <ListIterator.h>
 
-Vector<Process> Process::procs(MAX_PROCS);
+Array<Process> Process::procs(MAX_PROCS);
 List<Process> Process::wakeups;
 
 Process::Process(Address addr) : status(Stopped)
