@@ -20,7 +20,7 @@
 #include "stdio.h"
 #include "stdlib.h"
 
-int vprintf(char *format, va_list args)
+int vprintf(const char *format, va_list args)
 {
     char buf[1024];
     Size size, written = 0;
