@@ -17,7 +17,7 @@
 
 #include "string.h"
 
-char * strcat(char *dest, char *src)
+char * strcat(char *dest, const char *src)
 {
     char *s = dest;
 
