@@ -17,10 +17,10 @@
 
 #include "string.h"
 
-int strcpy(char *dest, char *src)
+int strcpy(char *dest, const char *src)
 {
     char *d = dest;
-    char *s = src;
+    const char *s = src;
     int count = 0;
 
     while (*s)
