@@ -17,7 +17,7 @@
 
 #include "string.h"
 
-char * strncat(char *dest, char *src, size_t n)
+char * strncat(char *dest, const char *src, size_t n)
 {
     char *s = dest;
 
